==> haskell-config-ini-0.2.4.0-59-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.4.0
id: config-ini-0.2.4.0-aHNYb6hkm1mVtph4t2d5
key: config-ini-0.2.4.0-aHNYb6hkm1mVtph4t2d5
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: 8491dfeb6c66bc5bf7433474d54bb0e6
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.6.5/site-local/config-ini-0.2.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/config-ini-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/config-ini-0.2.4.0
hs-libraries: HSconfig-ini-0.2.4.0-aHNYb6hkm1mVtph4t2d5
depends:
    base-4.12.0.0 containers-0.6.0.1
    megaparsec-7.0.5-CZJNdrmae7v2Ggr9WXcTF8 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-ini-0.2.4.0-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-config-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: config-ini
version: 0.2.4.0
id: config-ini-0.2.4.0-JcHNLta7dbTGfKItOak4Gr
key: config-ini-0.2.4.0-JcHNLta7dbTGfKItOak4Gr
license: BSD-3-Clause
copyright: ©2018 Getty Ritter
maintainer: Getty Ritter <config-ini@infinitenegativeutility.com>
author: Getty Ritter <config-ini@infinitenegativeutility.com>
homepage: https://github.com/aisamanra/config-ini
synopsis: A library for simple INI-based configuration files.
description:
    The @config-ini@ library is a set of small monadic languages
    for writing simple configuration languages with convenient,
    human-readable error messages.
    .
    > parseConfig :: IniParser (Text, Int, Bool)
    > parseConfig = section "NETWORK" $ do
    >   user <- field        "user"
    >   port <- fieldOf      "port" number
    >   enc  <- fieldFlagDef "encryption" True
    >   return (user, port, enc)
category: Configuration
abi: bd5732c07c6a00a04f6c3fb0b9aeca14
exposed: True
exposed-modules:
    Data.Ini.Config Data.Ini.Config.Bidir Data.Ini.Config.Raw
import-dirs: /usr/lib/ghc-8.6.5/site-local/config-ini-0.2.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/config-ini-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/config-ini-0.2.4.0
hs-libraries: HSconfig-ini-0.2.4.0-JcHNLta7dbTGfKItOak4Gr
depends:
    base-4.12.0.0 containers-0.6.0.1
    megaparsec-7.0.5-CZJNdrmae7v2Ggr9WXcTF8 text-1.2.3.1
    transformers-0.5.6.2
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
haddock-interfaces: /usr/share/doc/haskell-config-ini/html/config-ini.haddock
haddock-html: /usr/share/doc/haskell-config-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
